# kim-tools

![testing](https://github.com/openkim/kim-tools/actions/workflows/testing.yml/badge.svg)
[![docs](https://app.readthedocs.org/projects/kim-tools/badge/?version=latest)](https://kim-tools.readthedocs.io/en/latest/)
[![PyPI](https://img.shields.io/pypi/v/kim-tools.svg)](https://pypi.org/project/kim-tools/)

KIMTestDriver and SingleCrystalTestDriver classes for creating OpenKIM Test Drivers, and helper routines for writing
KIM Tests and Verification Checks. Documentation at https://kim-tools.readthedocs.io.
